[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- pysmime
  - pysmime.core: Core functions to verify, sign, encrypt and decrypt SMIME data, build just on top of M2Crypto library wrapper to OpenSSL.
  - pysmime.file: Functions to verify, sign, encrypt and decrypt SMIME files, build on top of pysmime/core.
  - pysmime.mail: Functions to verify, sign, encrypt and decrypt SMIME mail entity, build on top of pysmime/core.
  - pysmime.pkcs11: Interact with OpenSSL by M2Crypto library wrapper and OpenSC pkcs11 engine to access smart cards and retrieve private keys and certificates reference.
  - pysmime.util: Some useful functions.